package sun.security.krb5;

import java.io.IOException;
import sun.security.krb5.internal.KDCReqBody;
import sun.security.krb5.internal.crypto.Nonce;
import java.util.Arrays;
import sun.security.krb5.internal.PAEncTSEnc;
import sun.security.krb5.internal.Krb5;
import sun.security.krb5.internal.PAData;
import sun.security.krb5.internal.HostAddresses;
import sun.security.krb5.internal.KerberosTime;
import sun.security.krb5.internal.KDCOptions;
import sun.security.krb5.internal.ASReq;

public class KrbAsReq
{
    private ASReq asReqMessg;
    private boolean DEBUG;
    
    public KrbAsReq(EncryptionKey encryptionKey, KDCOptions new_kdcOptions, PrincipalName new_cname, PrincipalName tgsService, KerberosTime new_from, KerberosTime new_till, KerberosTime new_rtime, int[] new_eType, HostAddresses localAddresses, PAData[] array) throws KrbException, IOException {
        this.DEBUG = Krb5.DEBUG;
        if (new_kdcOptions == null) {
            new_kdcOptions = new KDCOptions();
        }
        if (new_kdcOptions.get(2) || new_kdcOptions.get(4) || new_kdcOptions.get(28) || new_kdcOptions.get(30) || new_kdcOptions.get(31)) {
            throw new KrbException(101);
        }
        if (!new_kdcOptions.get(6) && new_from != null) {
            new_from = null;
        }
        if (!new_kdcOptions.get(8) && new_rtime != null) {
            new_rtime = null;
        }
        PAData[] array2 = null;
        if (encryptionKey != null) {
            array2 = new PAData[] { new PAData(2, new EncryptedData(encryptionKey, new PAEncTSEnc().asn1Encode(), 1).asn1Encode()) };
        }
        if (array != null && array.length > 0) {
            if (array2 == null) {
                array2 = new PAData[array.length];
            }
            else {
                array2 = (PAData[])Arrays.copyOf(array2, array2.length + array.length);
            }
            System.arraycopy(array, 0, array2, array2.length - array.length, array.length);
        }
        if (new_cname.getRealm() == null) {
            throw new RealmException(601, "default realm not specified ");
        }
        if (this.DEBUG) {
            System.out.println(">>> KrbAsReq creating message");
        }
        if (localAddresses == null && Config.getInstance().useAddresses()) {
            localAddresses = HostAddresses.getLocalAddresses();
        }
        if (tgsService == null) {
            String realmAsString = new_cname.getRealmAsString();
            tgsService = PrincipalName.tgsService(realmAsString, realmAsString);
        }
        if (new_till == null) {
            new_till = new KerberosTime(0L);
        }
        this.asReqMessg = new ASReq(array2, new KDCReqBody(new_kdcOptions, new_cname, tgsService, new_from, new_till, new_rtime, Nonce.value(), new_eType, localAddresses, null, null));
        return;
    }
    
    byte[] encoding() throws IOException, Asn1Exception {
        return this.asReqMessg.asn1Encode();
    }
    
    ASReq getMessage() {
        return this.asReqMessg;
    }
}
